@@ -4,6 +4,8 @@
 
 import os
 import os.path
+import stat
+import time
 
 
 class FileLoader(object):
@@ -111,62 +113,85 @@ class ChainLoader(object):
         """
         for loader in self.loaders:
             source = loader.load(name)
-            if source:
+            if source is not None:
                 return source
         return None
 
 
+class PreprocessLoader(object):
+    """ Performs preprocessing of loaded template.
+    """
+
+    def __init__(self, engine, ctx=None):
+        self.engine = engine
+        self.ctx = ctx or {}
+
+    def list_names(self):
+        return self.engine.loader.list_names()
+
+    def load(self, name):
+        return self.engine.render(name, self.ctx, {}, {})
+
+
 def autoreload(engine, enabled=True):
-    """ Auto reload template if changes are detected in file. Limitation:
-        inherited and imported templates.
+    """ Auto reload template if changes are detected in file.
+
+        Limitation: master (inherited), imported and preprocessed templates.
+
+        It is recommended to use application server that supports
+        file reload instead.
     """
     if not enabled:
         return engine
-
-    import stat
-    from time import time
-
-    class AutoReloadProxy(object):
-
-        def __init__(self, engine):
-            self.engine = engine
-            self.names = {}
-
-        def get_template(self, name):
-            if self.file_changed(name):
-                self.remove(name)
-            return self.engine.get_template(name)
-
-        def render(self, name, ctx, local_defs, super_defs):
-            if self.file_changed(name):
-                self.remove(name)
-            return self.engine.render(name, ctx, local_defs, super_defs)
-
-        def remove(self, name):
-            self.engine.remove(name)
-
-        # region: internal details
-
-        def __getattr__(self, name):
-            return getattr(self.engine, name)
-
-        def file_changed(self, name):
-            try:
-                last_known_stamp = self.names[name]
-                current_time = int(time())
-                if current_time - last_known_stamp <= 2:
-                    return False
-            except KeyError:
-                last_known_stamp = 0
-
-            abspath = self.engine.loader.get_fullname(name)
-            if not abspath:
-                return False
-
-            last_modified_stamp = os.stat(abspath)[stat.ST_MTIME]
-            if last_modified_stamp <= last_known_stamp:
-                return False
-            self.names[name] = last_modified_stamp
-            return True
-
     return AutoReloadProxy(engine)
+
+
+# region: internal details
+
+class AutoReloadProxy(object):
+
+    def __init__(self, engine):
+        from warnings import warn
+        self.engine = engine
+        self.names = {}
+        warn('autoreload limitation: master (inherited), imported '
+             'and preprocessed templates. It is recommended to use '
+             'application server that supports file reload instead.',
+             stacklevel=3)
+
+    def get_template(self, name):
+        if self.file_changed(name):
+            self.remove(name)
+        return self.engine.get_template(name)
+
+    def render(self, name, ctx, local_defs, super_defs):
+        if self.file_changed(name):
+            self.remove(name)
+        return self.engine.render(name, ctx, local_defs, super_defs)
+
+    def remove(self, name):
+        self.engine.remove(name)
+
+    # region: internal details
+
+    def __getattr__(self, name):
+        return getattr(self.engine, name)
+
+    def file_changed(self, name):
+        try:
+            last_known_stamp = self.names[name]
+            current_time = int(time.time())
+            if current_time - last_known_stamp <= 2:
+                return False
+        except KeyError:
+            last_known_stamp = 0
+
+        abspath = self.engine.loader.get_fullname(name)
+        if not abspath:
+            return False
+
+        last_modified_stamp = os.stat(abspath)[stat.ST_MTIME]
+        if last_modified_stamp <= last_known_stamp:
+            return False
+        self.names[name] = last_modified_stamp
+        return True
